Re: [PATCH] diff-delta: bound hash list length to avoid O(m*n) behavior
- From
Junio C Hamano <junkio@cox.net>
- Date
- Mar 4, 2006, 02:39 UTC
- Message-ID
- <7vbqwnx79y.fsf@assigned-by-dhcp.cox.net>
- In-Reply-To
- <7vfylzx7t3.fsf@assigned-by-dhcp.cox.net>
Junio C Hamano <junkio@cox.net> writes:
Show 8 quoted lines
> The first round. The set of objects packed were from > today's Linus tip (everything down to epoch v2.6.12-rc2), 193309 > objects in total, on my Duron 750 with slow disks. > > real user sys bytes savings > master 11m17.121s 10m23.280s 0m47.290s 109045599 N/A > nico 25m37.058s 23m0.770s 2m20.460s 104401392 4.25% > jc 24m12.072s 21m45.120s 2m16.400s 104409761 4.25%
Minor correction in numbers. The size for nico and jc are swapped. jc variant created the smallest pack in this experiment.
Which puzzles me even more...